<?php
namespace Wpcafe_Multivendor\Core\Enqueue;

defined( 'ABSPATH' ) || exit;

use WpCafe\Traits\Wpc_Singleton;
use WpCafe\Utils\Wpc_Utilities;
use Wpcafe_Multivendor;

/**
 * Enqueue all css and js file class
 */
class Enqueue {

    use Wpc_Singleton;

    /**
     * Main calling function
     */
    public function init() {
        // backend asset
        add_action( 'admin_enqueue_scripts', [$this, 'admin_enqueue_assets'] );
        // frontend asset
        add_action( 'wp_enqueue_scripts', [$this, 'frontend_enqueue_assets'] );
    }
  

    /**
     * all js files function
     */
    public function admin_get_scripts() {
        $script_arr =  array(
            'wpcafe-multivendor'     => array(
                'src'     => \Wpcafe_Multivendor::assets_url() . 'js/admin.js',
                'version' => \Wpcafe_Multivendor::version(),
                'deps'    => ['jquery'],
            ),
        );
        
        return $script_arr;
    }

    /**
     * all css files function
     *
     * @param Type $var
     */
    public function admin_get_styles() {
        return array(
            'wpcafe-multivendor' => array(
                'src'     => \Wpcafe_Multivendor::assets_url() . 'css/admin.css',
                'version' => \Wpcafe_Multivendor::version(),
            ),
        );
    }

    /**
     * all js files function
     */
    public function frontend_get_scripts() {

        $script_arr = array(
            'wpcafe-multivendor-public'  => array(
                'src'     => \Wpcafe_Multivendor::assets_url() . 'js/public.js',
                'version' => \Wpcafe_Multivendor::version(),
                'deps'    => ['jquery'],
            ),
        );

        return $script_arr;

    }

    /**
     * all css files function
     */
    public function frontend_get_styles() {
        $enequeue =  array(
            'wpcafe-multivendor-public' => array(
                'src'     => \Wpcafe_Multivendor::assets_url() . 'css/public.css',
                'version' => \Wpcafe_Multivendor::version(),
            ),
        );

        return $enequeue;
    }

    
    /**
     * Enqueue admin js and css function
     *
     * @param  $var
     */
    public function admin_enqueue_assets() {
        wp_enqueue_style( 'wpcafe-multivendor', \Wpcafe_Multivendor::assets_url() . 'css/admin.css', [], \Wpcafe_Multivendor::version(), 'all' );
        
        // js
        $scripts = $this->admin_get_scripts();

        foreach ( $scripts as $key => $value ) {
            $deps       = !empty( $value['deps'] ) ? $value['deps'] : false;
            $version    = !empty( $value['version'] ) ? $value['version'] : false;
            wp_enqueue_script( $key, $value['src'], $deps, $version, true );
        }

        // css
        $styles = $this->admin_get_styles();

        foreach ( $styles as $key => $value ) {
            $deps       = isset( $value['deps'] ) ? $value['deps'] : false;
            $version    = !empty( $value['version'] ) ? $value['version'] : false;
            wp_enqueue_style( $key, $value['src'], $deps, $version, 'all' );
        }
    }

    /**
     * Enqueue admin js and css function
     */
    public function frontend_enqueue_assets() {
        // js
        $scripts = $this->frontend_get_scripts();

        foreach ( $scripts as $key => $value ) {
            $deps       = isset( $value['deps'] ) ? $value['deps'] : false;
            $version    = !empty( $value['version'] ) ? $value['version'] : false;

            wp_enqueue_script( $key, $value['src'], $deps, $version, true );
        }

        // css
        $styles = $this->frontend_get_styles();

        foreach ( $styles as $key => $value ) {
            $deps = isset( $value['deps'] ) ? $value['deps'] : false;
            $version    = !empty( $value['version'] ) ? $value['version'] : false;
            wp_enqueue_style( $key, $value['src'], $deps, $version, 'all' );
        }
        
    }
}


